.. Transonic documentation master file

.. include:: ../README.rst

.. toctree::
   :maxdepth: 2
   :caption: Backends

   backends

.. toctree::
   :maxdepth: 2
   :caption: Examples

   examples/classic
   examples/type_hints
   examples/using_jit
   examples/blocks
   examples/methods
   ipynb/executed/demo_compile_at_import
   ipynb/executed/demo_jit
   examples/inlined/txt
   examples/writing_benchmarks/bench
   ipynb/executed/bench_fxfy


Modules Reference
-----------------

Here is presented the organization of the package and the documentation of the
modules, classes and functions.

.. autosummary::
   :toctree: generated/
   :caption: Modules Reference

    transonic.aheadoftime
    transonic.analyses
    transonic.backends
    transonic.compiler
    transonic.config
    transonic.dist
    transonic.justintime
    transonic.log
    transonic.mpi
    transonic.run
    transonic.signatures
    transonic.typing
    transonic.util

.. toctree::
   :maxdepth: 1
   :caption: More

   Transonic forge on Heptapod <https://foss.heptapod.net/fluiddyn/transonic>
   Transonic in PyPI  <https://pypi.python.org/pypi/transonic/>
   changes
   roadmap
   thanks
   Advice for FluidDyn developers <http://fluiddyn.readthedocs.io/en/latest/advice_developers.html>
   for_dev


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
